from django import forms
from django.contrib.auth import forms as auth_forms

from benevalibre.utils.forms import CustomTapeformMixin

from .models import User


class PasswordFormMixin(CustomTapeformMixin):
    def apply_widget_options(self, field_name):
        if field_name.startswith('new_password'):
            field = self.fields[field_name]
            field.widget.attrs['autocomplete'] = 'new-password'


class AuthenticationForm(CustomTapeformMixin, auth_forms.AuthenticationForm):
    """
    Formulaire d'authentification de l'utilisateur.
    """

    error_messages = {
        'invalid_login': (
            "L'adresse mail et le mot de passe ne correspondent pas, "
            "veuillez réessayer."
        ),
        'inactive': (
            "Le compte est désactivé. Veuillez nous contacter pour plus "
            "d'informations."
        ),
    }


class PasswordResetForm(CustomTapeformMixin, auth_forms.PasswordResetForm):
    """
    Formulaire de demande de réinitialisation du mot de passe.
    """

    email = forms.EmailField(label="Adresse mail", max_length=254)


class SetPasswordForm(PasswordFormMixin, auth_forms.SetPasswordForm):
    """
    Formulaire de réinitialisation du mot de passe, sans avoir à saisir
    l'ancien.
    """


class RegistrationForm(CustomTapeformMixin, auth_forms.UserCreationForm):
    """
    Formulaire de demande de création d'un compte.
    """

    class Meta:
        model = User
        fields = ('email', 'first_name', 'last_name', 'pseudo')


class UserUpdateForm(CustomTapeformMixin, forms.ModelForm):
    """
    Formulaire d'édition du profil utilisateur.
    """

    class Meta:
        model = User
        fields = ('email', 'first_name', 'last_name', 'pseudo', 'avatar')


class ResendActivationForm(CustomTapeformMixin, forms.Form):
    """
    Formulaire de demande d'envoi du lien d'activation du compte.
    """

    email = forms.EmailField(label="Adresse mail", max_length=254)
