import django_tables2 as tables
from django_tables2.utils import A

from benevalibre.utils.html import fa_icon

from . import models


class AssociationIndexTable(tables.Table):
    update = tables.LinkColumn(
        'association:update',
        verbose_name="éditer",
        text=fa_icon('edit'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'update-link'}},
    )
    delete = tables.LinkColumn(
        'association:delete',
        verbose_name="effacer",
        text=fa_icon('trash-o'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'delete-link text-danger'}},
    )
    level = tables.LinkColumn(
        'association:level:index',
        text=fa_icon('tachometer'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'level-link'}},
        verbose_name='Niveaux',
    )
    project = tables.LinkColumn(
        'association:project:index',
        text=fa_icon('wrench'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'project-link'}},
        verbose_name='Projets',
    )
    category = tables.LinkColumn(
        'association:category:index',
        text=fa_icon('tags'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'category-link'}},
        verbose_name='Catégories',
    )
    role = tables.LinkColumn(
        'association:role:index',
        text=fa_icon('key-modern'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'role-link'}},
        verbose_name='Roles',
    )
    engagement = tables.LinkColumn(
        'association:engagement:index',
        text=fa_icon('users'),
        args=(A('pk'),),
        orderable=False,
        attrs={'a': {'class': 'engagement-link'}},
        verbose_name='Bénévoles',
    )
    name = tables.LinkColumn('association:update', args=(A('pk'),))

    class Meta:
        model = models.Association
        fields = (
            'name',
            'project',
            'category',
            'level',
            'role',
            'engagement',
            'update',
            'delete',
        )


class ProjectIndexTable(tables.Table):
    update = tables.LinkColumn(
        'association:project:update',
        verbose_name="éditer",
        text=fa_icon('edit'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'update-link'}},
    )
    delete = tables.LinkColumn(
        'association:project:delete',
        verbose_name="effacer",
        text=fa_icon('trash-o'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'delete-link text-danger'}},
    )
    name = tables.LinkColumn(
        'association:project:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Project
        fields = ('name', 'update', 'delete')


class RoleIndexTable(tables.Table):
    update = tables.LinkColumn(
        'association:role:update',
        verbose_name="éditer",
        text=fa_icon('edit'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'update-link'}},
    )
    delete = tables.LinkColumn(
        'association:role:delete',
        verbose_name="effacer",
        text=fa_icon('trash-o'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'delete-link text-danger'}},
    )
    name = tables.LinkColumn(
        'association:role:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Role
        fields = ('name', 'update', 'delete')


class LevelIndexTable(tables.Table):
    update = tables.LinkColumn(
        'association:level:update',
        verbose_name="éditer",
        text=fa_icon('edit'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'update-link'}},
    )
    delete = tables.LinkColumn(
        'association:level:delete',
        verbose_name="effacer",
        text=fa_icon('trash-o'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'delete-link text-danger'}},
    )
    name = tables.LinkColumn(
        'association:level:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Level
        fields = ('name', 'update', 'delete')


class EngagementIndexTable(tables.Table):
    update = tables.LinkColumn(
        'association:engagement:update',
        verbose_name="éditer",
        text=fa_icon('edit'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'update-link'}},
    )
    delete = tables.LinkColumn(
        'association:engagement:delete',
        verbose_name="effacer",
        text=fa_icon('trash-o'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'delete-link text-danger'}},
    )
    user = tables.LinkColumn(
        'association:engagement:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Engagement
        fields = ('user', 'role', 'update', 'delete')


class CategoryIndexTable(tables.Table):
    update = tables.LinkColumn(
        'association:category:update',
        verbose_name="éditer",
        text=fa_icon('edit'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'update-link'}},
    )
    delete = tables.LinkColumn(
        'association:category:delete',
        verbose_name="effacer",
        text=fa_icon('trash-o'),
        args=(A('association.id'), A('pk')),
        orderable=False,
        attrs={'a': {'class': 'delete-link text-danger'}},
    )
    name = tables.LinkColumn(
        'association:category:update', args=(A('association.id'), A('pk'))
    )

    class Meta:
        model = models.Category
        fields = ('name', 'instance_category', 'update', 'delete')
