from django import forms

from benevalibre.accounts.models import User
from benevalibre.association.models import Association
from benevalibre.utils.forms import CustomTapeformMixin

from . import models


class CreateForm(CustomTapeformMixin, forms.ModelForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        if 'association' in self.initial and self.initial['association']:
            # We dynamically limit the queryset to association's relations
            association = Association.objects.get(
                pk=self.initial['association']
            )
            self.fields['user'].queryset = User.objects.filter(
                engagement__in=association.engagement_set.all()
            )
            self.fields['level'].queryset = association.level_set.all()
            self.fields['category'].queryset = association.category_set.all()
            self.fields['project'].queryset = association.project_set.all()

    class Meta:
        model = models.Benevalo
        fields = '__all__'
        widgets = {
            'execution_date': forms.DateInput(format='%Y-%m-%d'),
            'execution_end_date': forms.DateInput(format='%Y-%m-%d'),
        }


class UpdateForm(CreateForm):
    pass
