from django import forms

from benevalibre.association.models import Engagement
from benevalibre.benevalo.models import Benevalo
from benevalibre.utils.forms import CustomTapeformMixin


class AssociatedEngagedBenevaloCreateForm(
    CustomTapeformMixin, forms.ModelForm
):
    def __init__(self, *args, **kwargs):
        self.association = kwargs.pop('association')

        super().__init__(*args, **kwargs)
        self.fields['category'].queryset = self.association.category_set.all()

        if not self.association.project_set.exists():
            del self.fields['project']
        else:
            self.fields[
                'project'
            ].queryset = self.association.project_set.all()

        if not self.association.level_set.exists():
            del self.fields['level']
        else:
            self.fields['level'].queryset = self.association.level_set.all()

    class Meta:
        model = Benevalo
        fields = [
            'title',
            'duration',
            'distance',
            'execution_date',
            'execution_end_date',
            'category',
            'project',
            'level',
            'description',
        ]
        widgets = {
            'execution_date': forms.DateInput(format='%Y-%m-%d'),
            'execution_end_date': forms.DateInput(format='%Y-%m-%d'),
        }


class AssociatedEngagedBenevaloUpdateForm(AssociatedEngagedBenevaloCreateForm):
    pass


class AssociatedBenevaloCreateForm(AssociatedEngagedBenevaloCreateForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields['user'].queryset = self.association.get_benevoles()

    class Meta:
        model = Benevalo
        fields = [
            'user',
            'title',
            'duration',
            'distance',
            'execution_date',
            'execution_end_date',
            'category',
            'project',
            'level',
            'description',
        ]
        widgets = {
            'execution_date': forms.DateInput(format='%Y-%m-%d'),
            'execution_end_date': forms.DateInput(format='%Y-%m-%d'),
        }


class AssociatedBenevaloUpdateForm(AssociatedBenevaloCreateForm):
    pass


class AssociationEngageForm(forms.Form):
    pass


class AssociatedEngagementUpdateForm(CustomTapeformMixin, forms.ModelForm):
    def __init__(self, *args, **kwargs):
        self.role_set = kwargs.pop('role_set')

        super().__init__(*args, **kwargs)
        self.fields['role'].queryset = self.role_set

    class Meta:
        model = Engagement
        fields = ['role']
