from django.urls import include, path

from benevalibre.utils.urls import crudipath

from . import views

app_name = 'board'

engaged_patterns = [
    path(
        '<int:engagement>/benevalo/',
        views.AssociatedEngagedBenevaloIndex.as_view(),
        name='benevalo',
    )
] + crudipath(views, '', 'AssociatedEngagement', '', create=False)


association_patterns = [
    path(
        '<int:association>/users/',
        views.AssociatedEngagementReadOnlyIndex.as_view(),
        name='user',
    ),
    path(
        '<int:association>/engage/',
        views.AssociationEngage.as_view(),
        name='engage',
    ),
    path(
        '<int:association>/my-benevalo/',
        include(
            (
                crudipath(views, '', 'AssociatedSelfBenevalo', ''),
                'self-benevalo',
            )
        ),
    ),
    path(
        '<int:association>/benevalo/',
        include((crudipath(views, '', 'AssociatedBenevalo', ''), 'benevalo')),
    ),
    path(
        '<int:association>/engagements/',
        include((engaged_patterns, 'engagement')),
    ),
] + (
    crudipath(views, '', 'Association', '', detail=True)
    + crudipath(views, '<int:association>/roles/', 'AssociatedRole', 'role')
    + crudipath(views, '<int:association>/levels/', 'AssociatedLevel', 'level')
    + crudipath(
        views, '<int:association>/projects/', 'AssociatedProject', 'project'
    )
    + crudipath(
        views,
        '<int:association>/categories/',
        'AssociatedCategory',
        'category',
    )
)

urlpatterns = [
    path('', views.Home.as_view(), name='home'),
    path('board/', views.EngagementIndex.as_view(), name='board'),
    path('associations/', include((association_patterns, 'association'))),
]
