import pytest

from benevalibre.accounts.models import User
from benevalibre.association import models
from benevalibre.instance.models import InstanceCategory


@pytest.fixture
def user(django_db_setup, django_db_blocker):
    with django_db_blocker.unblock():
        return User.objects.create(email="user@example.org")


@pytest.fixture
def foreign(django_db_setup, django_db_blocker):
    with django_db_blocker.unblock():
        return User.objects.create(email="foreign@example.org")


@pytest.fixture
def superuser(django_db_setup, django_db_blocker):
    with django_db_blocker.unblock():
        return User.objects.create(
            email="staff@example.org", is_superuser=True
        )


@pytest.fixture
def association(django_db_blocker):
    with django_db_blocker.unblock():
        association = models.Association.objects.create(
            name="AssoTest",
            description="""
                D'après wikipédia, en droit français des associations, une
                association loi de 1901 est, en France et dans de nombreux pays
                colonisés à l'époque par la France, une association à but non
                lucratif qui relève de la loi du 1er juillet 19011 mise en
                place par Waldeck-Rousseau (alors président du Conseil et
                ministre de l'Intérieur et des Cultes) et du décret du 16 août
                1901.
                """,
        )
        return association


@pytest.fixture
def role(django_db_blocker, association):
    with django_db_blocker.unblock():
        role = association.role_set.create(name='RoleTest')
        return role


@pytest.fixture
def engagement(django_db_blocker, user, association):
    with django_db_blocker.unblock():
        return models.Engagement.objects.create(
            role=models.Role.objects.get_benevole(),
            user=user,
            association=association,
        )


@pytest.fixture
def manager(django_db_blocker, user, association):
    with django_db_blocker.unblock():
        return models.Engagement.objects.create(
            role=models.Role.objects.get_dirigeant(),
            user=user,
            association=association,
        )


@pytest.fixture
def project(django_db_blocker, association):
    with django_db_blocker.unblock():
        return models.Project.objects.create(
            name="ProjetTest", association=association
        )


@pytest.fixture
def level(django_db_blocker, association):
    with django_db_blocker.unblock():
        return models.Level.objects.create(
            name="NiveauTest", association=association
        )


@pytest.fixture
def category(django_db_blocker, association):
    with django_db_blocker.unblock():
        instance_category = InstanceCategory.objects.create(
            name="InstanceCategoryTest"
        )
        return models.Category.objects.create(
            name="CatégorieTest",
            association=association,
            instance_category=instance_category,
        )


@pytest.fixture
def closed_registration(settings):
    settings.OPEN_REGISTRATION = False


@pytest.fixture
def moderated_registration(settings):
    settings.MODERATED_REGISTRATION = True
