from django.urls import reverse, reverse_lazy

from cruditor import views

from benevalibre.utils.html import fa_icon
from benevalibre.utils.views import StaffCruditorMixin

from . import forms, models, tables


class DefaultRoleViewMixin(StaffCruditorMixin):
    model = models.DefaultRole
    success_url = reverse_lazy('instance:role:index')


class DefaultRoleIndex(DefaultRoleViewMixin, views.CruditorListView):
    title = "Liste des roles par défaut"
    table_class = tables.DefaultRoleIndexTable

    def get_titlebutton_condition(self):
        return True

    def get_titlebutton_url(self):
        return reverse('instance:role:create')

    def get_titlebutton_label(self):
        return fa_icon('plus-circle', "Ajouter un rôle par défaut")


class DefaultRoleCreate(DefaultRoleViewMixin, views.CruditorAddView):
    form_class = forms.DefaultRoleCreateForm


class DefaultRoleUpdate(DefaultRoleViewMixin, views.CruditorChangeView):
    form_class = forms.DefaultRoleUpdateForm

    def get_delete_url(self):
        return reverse('instance:role:delete', args=(self.object.pk,))


class DefaultRoleDelete(DefaultRoleViewMixin, views.CruditorDeleteView):
    pass


class DefaultLevelViewMixin(StaffCruditorMixin):
    model = models.DefaultLevel
    success_url = reverse_lazy('instance:level:index')


class DefaultLevelIndex(DefaultLevelViewMixin, views.CruditorListView):
    title = "Liste des niveaux de bénévolat par défaut"
    table_class = tables.DefaultLevelIndexTable

    def get_titlebutton_condition(self):
        return True

    def get_titlebutton_url(self):
        return reverse('instance:level:create')

    def get_titlebutton_label(self):
        return fa_icon('plus-circle', "Ajouter un niveau par défaut")


class DefaultLevelCreate(DefaultLevelViewMixin, views.CruditorAddView):
    form_class = forms.DefaultLevelCreateForm


class DefaultLevelUpdate(DefaultLevelViewMixin, views.CruditorChangeView):
    form_class = forms.DefaultLevelUpdateForm

    def get_delete_url(self):
        return reverse('instance:level:delete', args=(self.object.pk,))


class DefaultLevelDelete(DefaultLevelViewMixin, views.CruditorDeleteView):
    pass


class InstanceCategoryViewMixin(StaffCruditorMixin):
    model = models.InstanceCategory
    success_url = reverse_lazy('instance:instance_category:index')


class InstanceCategoryIndex(InstanceCategoryViewMixin, views.CruditorListView):
    title = "Liste des catégories d'instance"
    table_class = tables.InstanceCategoryIndexTable

    def get_titlebutton_condition(self):
        return True

    def get_titlebutton_url(self):
        return reverse('instance:instance_category:create')

    def get_titlebutton_label(self):
        return fa_icon('plus-circle', "Ajouter une catégorie d'instance")


class InstanceCategoryCreate(InstanceCategoryViewMixin, views.CruditorAddView):
    form_class = forms.InstanceCategoryCreateForm


class InstanceCategoryUpdate(
    InstanceCategoryViewMixin, views.CruditorChangeView
):
    form_class = forms.InstanceCategoryUpdateForm

    def get_delete_url(self):
        return reverse(
            'instance:instance_category:delete', args=(self.object.pk,)
        )


class InstanceCategoryDelete(
    InstanceCategoryViewMixin, views.CruditorDeleteView
):
    pass


class DefaultCategoryViewMixin(StaffCruditorMixin):
    model = models.DefaultCategory
    success_url = reverse_lazy('instance:category:index')


class DefaultCategoryIndex(DefaultCategoryViewMixin, views.CruditorListView):
    title = "Liste des catégories de bénévolat par défaut"
    table_class = tables.DefaultCategoryIndexTable

    def get_titlebutton_condition(self):
        return True

    def get_titlebutton_url(self):
        return reverse('instance:category:create')

    def get_titlebutton_label(self):
        return fa_icon('plus-circle', "Ajouter une catégorie par défaut")


class DefaultCategoryCreate(DefaultCategoryViewMixin, views.CruditorAddView):
    form_class = forms.DefaultCategoryCreateForm


class DefaultCategoryUpdate(
    DefaultCategoryViewMixin, views.CruditorChangeView
):
    form_class = forms.DefaultCategoryUpdateForm

    def get_delete_url(self):
        return reverse('instance:category:delete', args=(self.object.pk,))


class DefaultCategoryDelete(
    DefaultCategoryViewMixin, views.CruditorDeleteView
):
    pass
