from django import forms

from tapeforms.contrib.bootstrap import BootstrapTapeformMixin


class CustomTapeformMixin(BootstrapTapeformMixin):
    """
    Mixin pour produire des formulaires intégrés avec Bootstrap.

    Il étends le mixin fournis avec `tapeforms` afin d'utiliser les classes
    personnalisées (custom forms) pour les champs de type checkbox et select.
    """

    #: Template à étendre pour la disposition du formulaire.
    base_layout_template = BootstrapTapeformMixin.layout_template

    def get_field_container_css_class(self, bound_field):
        if isinstance(bound_field.field.widget, forms.CheckboxInput):
            return 'form-group custom-control custom-checkbox'

        return super().get_field_container_css_class(bound_field)

    def get_field_label_css_class(self, bound_field):
        if isinstance(bound_field.field.widget, forms.CheckboxInput):
            return 'custom-control-label'

        return super().get_field_label_css_class(bound_field)

    def get_widget_css_class(self, field_name, field):
        if isinstance(field.widget, forms.Select):
            return 'custom-select'

        if isinstance(field.widget, forms.CheckboxInput):
            return 'custom-control-input'

        return super().get_widget_css_class(field_name, field)
