from django.contrib.auth.models import AnonymousUser
from django.views.generic import TemplateView

import pytest

from ..views import PageMixin
from . import count_text_in_content


class Page(PageMixin, TemplateView):
    page_title = "Titre de la page"
    template_name = 'base.html'


# TESTS
# ------------------------------------------------------------------------------


class TestPageMixin:
    @classmethod
    @pytest.fixture(autouse=True)
    def setup_class(cls, rf):
        cls.request = rf.get('/')
        cls.request.user = AnonymousUser()
        cls.view = Page()
        cls.view.request = cls.request

    def test_page_title(self):
        assert self.view.get_page_title() == "Titre de la page"

    def test_page_context(self):
        assert self.view.get_page_context() == {'title': "Titre de la page"}

    def test_response(self):
        response = self.view.dispatch(self.request)
        assert response.status_code == 200
        assert 'page' in response.context_data
        assert count_text_in_content(response, "Titre de la page")
